@@ -26,6 +26,7 @@
 
 import os
 
+from miss_hit_core import pathutil
 from miss_hit_core.config import Config, METRICS
 from miss_hit_core.errors import ICE, Message_Handler
 from miss_hit_core.m_ast import *
@@ -621,7 +622,7 @@ class MATLAB_Parser:
             l_functions, l_more_pragmas = self.parse_function_list()
             cunit = Function_File(os.path.basename(self.lexer.filename),
                                   os.path.dirname(
-                                      os.path.abspath(self.lexer.filename)),
+                                      pathutil.abspath(self.lexer.filename)),
                                   self.lexer.get_file_loc(),
                                   self.lexer.line_count(),
                                   l_functions,
@@ -670,7 +671,7 @@ class MATLAB_Parser:
 
         return Script_File(os.path.basename(self.lexer.filename),
                            os.path.dirname(
-                               os.path.abspath(self.lexer.filename)),
+                               pathutil.abspath(self.lexer.filename)),
                            self.lexer.get_file_loc(),
                            self.lexer.line_count(),
                            Sequence_Of_Statements(statements),
@@ -706,7 +707,7 @@ class MATLAB_Parser:
 
         return Script_File(os.path.basename(self.lexer.filename),
                            os.path.dirname(
-                               os.path.abspath(self.lexer.filename)),
+                               pathutil.abspath(self.lexer.filename)),
                            self.lexer.get_file_loc(),
                            self.lexer.line_count(),
                            Sequence_Of_Statements(statements),
@@ -721,7 +722,7 @@ class MATLAB_Parser:
 
         return Class_File(os.path.basename(self.lexer.filename),
                           os.path.dirname(
-                              os.path.abspath(self.lexer.filename)),
+                              pathutil.abspath(self.lexer.filename)),
                           self.lexer.get_file_loc(),
                           self.lexer.line_count(),
                           n_classdef,
@@ -1257,7 +1258,8 @@ class MATLAB_Parser:
             rv = Metric_Justification_Pragma(
                 t_pragma, t_pragma_kind,
                 t_tool, t_param, n_reason,
-                self.cfg.style_config["regex_tickets"])
+                self.cfg.style_config["regex_tickets"],
+                self.cfg.ignore_pragmas_with_tickets)
         elif t_pragma_kind.value == "Tag":
             rv = Tag_Pragma(t_pragma, t_pragma_kind, l_tags)
         elif t_pragma_kind.value == "No_Tracing":
@@ -1534,8 +1536,10 @@ class MATLAB_Parser:
         return self.parse_precedence_2()
 
     # 4. Unary plus (+), unary minus (-), logical negation (~)
+    #
+    # In Octave ! is also the the logical negation operator.
     def parse_precedence_4(self):
-        if self.peek("OPERATOR") and self.nt.value in ("+", "-", "~"):
+        if self.peek("OPERATOR") and self.nt.value in ("+", "-", "~", "!"):
             self.match("OPERATOR")
             t_op = self.ct
             rhs = self.parse_precedence_4()
@@ -1597,13 +1601,16 @@ class MATLAB_Parser:
 
     # 8. Less than (<), less than or equal to (<=), greater than (>),
     #    greater than or equal to (>=), equal to (==), not equal to (~=)
+    #
+    # In Octave we also get != as not equal
     def parse_precedence_8(self):
         rv = self.parse_range_expression()
 
         chain_length = 1
         while self.peek("OPERATOR") and self.nt.value in ("<", "<=",
                                                           ">", ">=",
-                                                          "==", "~="):
+                                                          "==", "~=",
+                                                          "!="):
             chain_length += 1
             self.match("OPERATOR")
             t_op = self.ct
